@@ -1,6 +1,6 @@
 # ABSTRACT: ArangoDB Collection object
 package Arango::Tango::Collection;
-$Arango::Tango::Collection::VERSION = '0.013';
+$Arango::Tango::Collection::VERSION = '0.014';
 use warnings;
 use strict;
 
@@ -9,6 +9,13 @@ use Arango::Tango::API;
 BEGIN {
     Arango::Tango::API::_install_methods "Arango::Tango::Collection" => {
 
+        document => {
+            rest => [ get => '{{database}}_api/document/{name}/{key}' ],
+            inject_properties => [ 'database', 'name' ],
+            signature => ['key'],
+            ## FIXME - Header parameters still not supported
+           },
+
         load => {
             rest   => [ put => '{{database}}_api/collection/{name}/load'],
             schema => { count => { type => 'integer' }},
@@ -139,7 +146,7 @@ Arango::Tango::Collection - ArangoDB Collection object
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 USAGE
 
@@ -189,6 +196,12 @@ optionally the document data in the collection.
 
 In addition to the above C<checksum>, the result also contains the number of documents.
 
+=head2 C<document>
+
+   $doc = $collection->document("doc_key");
+
+Retrieves a document given a specific key. The header options are not supported yet.
+
 =head2 C<figures>
 
    $figures = $collection->figures;
@@ -288,7 +301,7 @@ Alberto Simões <ambs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019-2020 by Alberto Simões.
+This software is copyright (c) 2019-2021 by Alberto Simões.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
